@@ -1,7 +1,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-24 10:42:34
-:LastEditTime: 2022-12-06 09:54:58
+:LastEditTime: 2022-12-06 18:11:52
 :LastEditors: HuangJingCan
 :Description: StudioBaseHandler
 """
@@ -16,7 +16,7 @@ from seven_studio.models.db_models.menu.menu_info_model_ex import *
 from seven_studio.models.db_models.role.role_user_model import *
 from seven_studio.models.db_models.role.role_power_model_ex import *
 from seven_studio.models.db_models.log.log_action_model import *
-from seven_studio.models.seven_model import PageInfo
+from seven_studio.models.seven_model import *
 from seven_studio.models.enum import *
 
 
