@@ -1,8 +1,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-03-17 16:12:54
-:LastEditTime: 2020-12-25 10:04:37
-:LastEditors: ChenXiaolei
+:LastEditTime: 2022-12-06 09:48:49
+:LastEditors: HuangJingCan
 :Description: 文件操作相关接口
 """
 from seven_studio.handlers.studio_base import *
@@ -36,7 +36,7 @@ class GetStoragePathListHandler(StudioBaseHandler):
 
         p_dict, total = file_storage_path_model.get_dict_page_list("*", page_index, page_size, condition, "", order)
 
-        self.reponse_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
+        return self.response_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
 
 
 class GetStoragePathDataHandler(StudioBaseHandler):
@@ -58,7 +58,7 @@ class GetStoragePathDataHandler(StudioBaseHandler):
         file_storage_path_model = FileStoragePathModel(self.get_file_context_key())
         p_dict = file_storage_path_model.get_dict_list("", "FileStoragePathID,StoragePathName")
 
-        self.reponse_json_success(p_dict)
+        return self.response_json_success(p_dict)
 
 
 class SaveStoragePathHandler(StudioBaseHandler):
@@ -88,14 +88,14 @@ class SaveStoragePathHandler(StudioBaseHandler):
 
         # 验证数据
         if storage_path_name == "":
-            return self.reponse_common("StoragePathNameEmpty", "存储名称参数为空")
+            return self.response_common("StoragePathNameEmpty", "存储名称参数为空")
 
         file_storage_path_model = FileStoragePathModel(self.get_file_context_key())
         file_storage_path = FileStoragePath()
         if file_storage_path_id != "":
             file_storage_path = file_storage_path_model.get_entity_by_id(file_storage_path_id)
             if not file_storage_path:
-                return self.reponse_common("NoExist", "数据不存在")
+                return self.response_common("NoExist", "数据不存在")
 
         # 赋值
         file_storage_path.StoragePathName = storage_path_name
@@ -114,7 +114,7 @@ class SaveStoragePathHandler(StudioBaseHandler):
             file_storage_path.FileStoragePathID = UUIDHelper.get_uuid()
             file_storage_path_model.add_entity(file_storage_path)
 
-        self.reponse_json_success(file_storage_path)
+        return self.response_json_success(file_storage_path)
 
 
 class DeleteStoragePathHandler(StudioBaseHandler):
@@ -132,11 +132,11 @@ class DeleteStoragePathHandler(StudioBaseHandler):
         """
         file_storage_path_id = self.get_param("FileStoragePathID")
         if file_storage_path_id == "":
-            return self.reponse_common("FileStoragePathIDEmpty", "存储配置ID为空")
+            return self.response_common("FileStoragePathIDEmpty", "存储配置ID为空")
 
         FileStoragePathModel(self.get_file_context_key()).del_entity("FileStoragePathID=%s", file_storage_path_id)
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class GetResourceListHandler(StudioBaseHandler):
@@ -159,7 +159,7 @@ class GetResourceListHandler(StudioBaseHandler):
 
         p_dict, total = file_resource_model.get_dict_page_list("*", page_index, page_size, condition, "", order)
 
-        self.reponse_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
+        return self.response_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
 
 
 class GetResourceInfoHandler(StudioBaseHandler):
@@ -178,7 +178,7 @@ class GetResourceInfoHandler(StudioBaseHandler):
         file_resource_model = FileResourceModel(self.get_file_context_key())
         p_dict = file_resource_model.get_dict_by_id(self.get_page_cote_id())
 
-        self.reponse_json_success(p_dict)
+        return self.response_json_success(p_dict)
 
 
 class SaveResourceHandler(StudioBaseHandler):
@@ -201,16 +201,16 @@ class SaveResourceHandler(StudioBaseHandler):
 
         # 验证数据
         if file_resource_name == "":
-            return self.reponse_common("FileResourceNameEmpty", "FileResourceName参数为空")
+            return self.response_common("FileResourceNameEmpty", "FileResourceName参数为空")
         if file_resource_code == "":
-            return self.reponse_common("FileResourceCodeEmpty", "FileResourceCode参数为空")
+            return self.response_common("FileResourceCodeEmpty", "FileResourceCode参数为空")
 
         file_resource_model = FileResourceModel(self.get_file_context_key())
         file_resource = FileResource()
         if file_resource_id != "":
             file_resource = file_resource_model.get_entity_by_id(file_resource_id)
             if not file_resource:
-                return self.reponse_common("NoExist", "数据不存在")
+                return self.response_common("NoExist", "数据不存在")
 
         # 赋值保存
         file_resource.FileResourceName = file_resource_name
@@ -222,7 +222,7 @@ class SaveResourceHandler(StudioBaseHandler):
             file_resource.FileResourceID = UUIDHelper.get_uuid()
             file_resource_model.add_entity(file_resource)
 
-        self.reponse_json_success(file_resource)
+        return self.response_json_success(file_resource)
 
 
 class DeleteResourceHandler(StudioBaseHandler):
@@ -240,11 +240,11 @@ class DeleteResourceHandler(StudioBaseHandler):
         """
         file_resource_id = self.get_param("FileResourceID")
         if file_resource_id == "":
-            return self.reponse_common("FileResourceIDEmpty", "资源ID为空")
+            return self.response_common("FileResourceIDEmpty", "资源ID为空")
 
         FileResourceModel(self.get_file_context_key()).del_entity("FileResourceID=%s", file_resource_id)
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class GetRestrictListHandler(StudioBaseHandler):
@@ -257,7 +257,7 @@ class GetRestrictListHandler(StudioBaseHandler):
         """
         :description: 获取上传限制
         :param {type} 
-        :return: reponse_json_success
+        :return: response_json_success
         :last_editors: HuangJingCan
         """
         condition = ""
@@ -280,7 +280,7 @@ class GetRestrictListHandler(StudioBaseHandler):
             source_dict_list = DictUtil.merge_dict_list(source_dict_list, "FileStoragePathID", merge_dict_list, "FileStoragePathID", "FileStoragePathID,StoragePathName")
         page_dict = self.get_dict_page_info_list(page_index, page_size, source_dict_list)
 
-        self.reponse_json_success(page_dict)
+        return self.response_json_success(page_dict)
 
 
 class SaveRestrictHandler(StudioBaseHandler):
@@ -293,7 +293,7 @@ class SaveRestrictHandler(StudioBaseHandler):
         """
         :description: SaveRestrict
         :param id：id
-        :return: reponse_json_success
+        :return: response_json_success
         :last_editors: HuangJingCan
         """
         # 获取参数
@@ -322,20 +322,20 @@ class SaveRestrictHandler(StudioBaseHandler):
 
         # 验证数据
         if restrict_name == "":
-            return self.reponse_common("RestrictNameEmpty", "RestrictName参数为空")
+            return self.response_common("RestrictNameEmpty", "RestrictName参数为空")
         if restrict_code == "":
-            return self.reponse_common("RestrictCodeEmpty", "RestrictCode参数为空")
+            return self.response_common("RestrictCodeEmpty", "RestrictCode参数为空")
 
         file_restrict_model = FileRestrictModel(self.get_file_context_key())
         file_restrict = FileRestrict()
         if file_restrict_id != "":
             file_restrict = file_restrict_model.get_entity_by_id(file_restrict_id)
             if not file_restrict:
-                return self.reponse_common("NoExistFileResource", "数据不存在")
+                return self.response_common("NoExistFileResource", "数据不存在")
         page_cote_id = self.get_page_cote_id()
         file_resource = FileResourceModel(self.get_file_context_key()).get_entity_by_id(page_cote_id)
         if not file_resource:
-            return self.reponse_common("NoExistFileResource", "数据不存在")
+            return self.response_common("NoExistFileResource", "数据不存在")
 
         # 赋值保存
         file_restrict.ResourceCode = file_resource.FileResourceCode
@@ -368,7 +368,7 @@ class SaveRestrictHandler(StudioBaseHandler):
             file_restrict.FileRestrictID = UUIDHelper.get_uuid()
             file_restrict_model.add_entity(file_restrict)
 
-        self.reponse_json_success(file_restrict)
+        return self.response_json_success(file_restrict)
 
 
 class DeleteRestrictHandler(StudioBaseHandler):
@@ -386,11 +386,11 @@ class DeleteRestrictHandler(StudioBaseHandler):
         """
         file_restrict_id = self.get_param("FileRestrictID")
         if file_restrict_id == "":
-            return self.reponse_common("FileRestrictIDEmpty", "FileRestrictID为空")
+            return self.response_common("FileRestrictIDEmpty", "FileRestrictID为空")
 
         FileRestrictModel(self.get_file_context_key()).del_entity("FileRestrictID=%s", file_restrict_id)
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class GetWaterImageListHandler(StudioBaseHandler):
@@ -413,7 +413,7 @@ class GetWaterImageListHandler(StudioBaseHandler):
 
         p_dict, total = file_water_image_model.get_dict_page_list("*", page_index, page_size, condition, "", order)
 
-        self.reponse_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
+        return self.response_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
 
 
 class GetWaterImageDataHandler(StudioBaseHandler):
@@ -432,7 +432,7 @@ class GetWaterImageDataHandler(StudioBaseHandler):
         file_water_image_model = FileWaterImageModel(self.get_file_context_key())
         p_dict = file_water_image_model.get_dict_list(field="WaterImageID,WaterName")
 
-        self.reponse_json_success(p_dict)
+        return self.response_json_success(p_dict)
 
 
 class SaveWaterImageHandler(StudioBaseHandler):
@@ -447,7 +447,7 @@ class SaveWaterImageHandler(StudioBaseHandler):
         :param WaterImageID：水印图片id 
         :param WaterImagePath：水印图片路径
         :param WaterName：水印图片名称
-        :return: reponse_json_success
+        :return: response_json_success
         :last_editors: HuangJingCan
         """
         # 获取参数
@@ -457,14 +457,14 @@ class SaveWaterImageHandler(StudioBaseHandler):
 
         # 验证数据
         if water_name == "":
-            return self.reponse_common("WaterNameEmpty", "水印名称为空")
+            return self.response_common("WaterNameEmpty", "水印名称为空")
 
         file_water_image_model = FileWaterImageModel(self.get_file_context_key())
         file_water_image = FileWaterImage()
         if water_image_id != "":
             file_water_image = file_water_image_model.get_entity_by_id(water_image_id)
             if not file_water_image:
-                return self.reponse_common("NoExist", "数据不存在")
+                return self.response_common("NoExist", "数据不存在")
 
         # 赋值
         file_water_image.WaterImagePath = water_image_path
@@ -476,7 +476,7 @@ class SaveWaterImageHandler(StudioBaseHandler):
             file_water_image.WaterImageID = UUIDHelper.get_uuid()
             file_water_image_model.add_entity(file_water_image)
 
-        self.reponse_json_success(file_water_image)
+        return self.response_json_success(file_water_image)
 
 
 class DeleteWaterImageHandler(StudioBaseHandler):
@@ -494,11 +494,11 @@ class DeleteWaterImageHandler(StudioBaseHandler):
         """
         water_image_id = self.get_param("WaterImageID")
         if water_image_id == "":
-            return self.reponse_common("WaterImageIDEmpty", "WaterImageID为空")
+            return self.response_common("WaterImageIDEmpty", "WaterImageID为空")
 
         FileWaterImageModel(self.get_file_context_key()).del_entity("WaterImageID=%s", water_image_id)
 
-        self.reponse_json_success()
+        return self.response_json_success()
 
 
 class GetHistoryListHandler(StudioBaseHandler):
@@ -521,7 +521,7 @@ class GetHistoryListHandler(StudioBaseHandler):
 
         p_dict, total = file_history_model.get_dict_page_list("*", page_index, page_size, condition, "", order)
 
-        self.reponse_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
+        return self.response_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))
 
 
 class DeleteHistoryHandler(StudioBaseHandler):
@@ -539,7 +539,7 @@ class DeleteHistoryHandler(StudioBaseHandler):
         """
         file_history_id = self.get_param("FileHistoryID")
         if file_history_id == "":
-            return self.reponse_common("FileHistoryIDEmpty", "FileHistoryID为空")
+            return self.response_common("FileHistoryIDEmpty", "FileHistoryID为空")
 
         result = 0
         file_context_key = self.get_file_context_key()
@@ -566,4 +566,4 @@ class DeleteHistoryHandler(StudioBaseHandler):
         if result > 0:
             file_history_model.del_entity("FileHistoryID=%s", file_history_id)
 
-        self.reponse_json_success()
\ No newline at end of file
+        return self.response_json_success()
\ No newline at end of file
