@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-22 14:32:40
-:LastEditTime: 2022-12-06 17:39:26
+:LastEditTime: 2022-12-06 18:04:03
 :LastEditors: HuangJingCan
 :Description: 栏目扩展类
 """
@@ -442,6 +442,8 @@ class MenuInfoModelEx(MenuInfoModel):
         for menu in menu_list:
             have_child = 1 if self.get_total("ParentID=%s", params=[menu.MenuID]) > 0 else 0
             menu.HaveChild = have_child
+            id_list = menu.IDPath.strip(',').split(',')
+            menu.Depth = len(id_list)
 
             MenuInfoModelEx(sub_table="copy").add_entity(menu)
 
